@@ -1378,9 +1378,16 @@ def http_request(
             # Retrieve the identification of the RESTful API application that the
             # HTTP request is sent to.  Check the signature of the HTTP request when
             # required.
-            consumer_key = request.get_header('X-API-Key', data_type=HttpRequest.ArgumentDataType.hexadecimal)
+            consumer_key = request.get_header(
+                'X-API-Key',
+                data_type=HttpRequest.ArgumentDataType.hexadecimal,
+                is_required=False
+            )
+
             if signature_required or consumer_key:
                 request.app_id = get_request_application_id(request, signature_required)
+            else
+                request.app_id = None
 
             # Retrieve the version of the RESTful API that the client application
             # has integrated, and detailed information about this client
